@@ -1,5 +1,3 @@
-{-# LANGUAGE CPP #-}
-
 module Main (main) where
 
 import Data.Void
@@ -8,10 +6,6 @@ import Test.Hspec.Megaparsec
 import Text.Megaparsec
 import Text.Megaparsec.Char
 
-#if !MIN_VERSION_base(4,13,0)
-import Data.Semigroup ((<>))
-#endif
-
 type Parser = Parsec Void String
 
 -- | Toy tests, just an example of usage.
